==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/tileentity/TileEntityBookshelfRenderer.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.block.BlockGomoku;
import com.github.tartaricacid.touhoulittlemaid.client.model.BookshelfModel;
import com.github.tartaricacid.touhoulittlemaid.tileentity.TileEntityBookshelf;
import net.minecraft.class_1921;
import net.minecraft.class_2350;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_5614;
import net.minecraft.class_7833;

public class TileEntityBookshelfRenderer extends TileEntityJoyRenderer<TileEntityBookshelf> {
    private static final class_2960 TEXTURE = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "textures/entity/bookshelf.png");
    private final BookshelfModel model;

    public TileEntityBookshelfRenderer(class_5614.class_5615 context) {
        model = new BookshelfModel(context.method_32140(BookshelfModel.LAYER));
    }

    @Override
    public void render(TileEntityBookshelf bookshelf, float partialTick, class_4587 poseStack, class_4597 bufferIn, int combinedLightIn, int combinedOverlayIn) {
        class_2350 facing = bookshelf.method_11010().method_11654(BlockGomoku.FACING);
        poseStack.method_22903();
        poseStack.method_22904(0.5, 1.5, 0.5);
        poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
        poseStack.method_22907(class_7833.field_40715.rotationDegrees(180 - facing.method_10161() * 90));
        class_4588 buffer = bufferIn.getBuffer(class_1921.method_23578(TEXTURE));
        model.renderToBuffer(poseStack, buffer, combinedLightIn, combinedOverlayIn, 1.0F, 1.0F, 1.0F, 1.0F);
        poseStack.method_22909();
    }

    @Override
    public boolean shouldRenderOffScreen(TileEntityBookshelf te) {
        return true;
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.0.7-neo1.3.6-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/tileentity/TileEntityBookshelfRenderer.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.block.BlockGomoku;
import com.github.tartaricacid.touhoulittlemaid.client.model.bedrock.SimpleBedrockModel;
import com.github.tartaricacid.touhoulittlemaid.client.resource.BedrockModelLoader;
import com.github.tartaricacid.touhoulittlemaid.tileentity.TileEntityBookshelf;
import net.minecraft.class_1297;
import net.minecraft.class_1921;
import net.minecraft.class_2350;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_5614;
import net.minecraft.class_7833;
import net.minecraft.class_827;

public class TileEntityBookshelfRenderer implements class_827<TileEntityBookshelf> {
    private static final class_2960 TEXTURE = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "textures/bedrock/block/bookshelf.png");
    private final SimpleBedrockModel<class_1297> model;

    public TileEntityBookshelfRenderer(class_5614.class_5615 context) {
        model = BedrockModelLoader.getModel(BedrockModelLoader.BOOKSHELF);
    }

    @Override
    public void render(TileEntityBookshelf bookshelf, float partialTick, class_4587 poseStack, class_4597 bufferIn, int combinedLightIn, int combinedOverlayIn) {
        class_2350 facing = bookshelf.method_11010().method_11654(BlockGomoku.FACING);
        poseStack.method_22903();
        poseStack.method_22904(0.5, 1.5, 0.5);
        poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
        poseStack.method_22907(class_7833.field_40715.rotationDegrees(180 - facing.method_10161() * 90));
        class_4588 buffer = bufferIn.getBuffer(class_1921.method_23578(TEXTURE));
        model.method_60879(poseStack, buffer, combinedLightIn, combinedOverlayIn);
        poseStack.method_22909();
    }

    @Override
    public boolean shouldRenderOffScreen(TileEntityBookshelf te) {
        return true;
    }
}
